pub struct QuicPacket {
pub short_header: Option<QuicShortHeader>,
pub long_header: Option<QuicLongHeader>,
pub payload_bytes_count: Option<u64>,
pub frames: Option<Vec<QuicFrame>>,
}Expand description
Parsed Quic Packet contents
Fields
short_header: Option<QuicShortHeader>Quic Short header
long_header: Option<QuicLongHeader>Quic Long header
payload_bytes_count: Option<u64>The number of bytes contained in the estimated payload
frames: Option<Vec<QuicFrame>>Implementations
Sourceimpl QuicPacket
impl QuicPacket
Sourcepub fn vec_u8_to_hex_string(vec: &[u8]) -> String
pub fn vec_u8_to_hex_string(vec: &[u8]) -> String
Processes the connection ID bytes array to a hex string
pub fn get_var_len(a: u8) -> Result<usize, QuicError>
pub fn slice_to_u64(data: &[u8]) -> Result<u64, QuicError>
pub fn access_data( data: &[u8], start: usize, end: usize, ) -> Result<&[u8], QuicError>
Sourcepub fn parse_from(
conn: &mut QuicConn,
data: &[u8],
offset: usize,
dir: bool,
) -> Result<(QuicPacket, usize), QuicError>
pub fn parse_from( conn: &mut QuicConn, data: &[u8], offset: usize, dir: bool, ) -> Result<(QuicPacket, usize), QuicError>
Parses Quic packet from bytes
Sourceimpl QuicPacket
impl QuicPacket
Sourcepub fn header_type(&self) -> &str
pub fn header_type(&self) -> &str
Returns the header type of the Quic packet (ie. “long” or “short”)
Sourcepub fn packet_type(&self) -> Result<LongHeaderPacketType, QuicError>
pub fn packet_type(&self) -> Result<LongHeaderPacketType, QuicError>
Returns the packet type of the Quic packet
Sourcepub fn dcid(&self) -> &str
pub fn dcid(&self) -> &str
Returns the destination connection ID of the Quic packet or an empty string if it does not exist
Sourcepub fn scid(&self) -> &str
pub fn scid(&self) -> &str
Returns the source connection ID of the Quic packet or an empty string if it does not exist
Sourcepub fn payload_bytes_count(&self) -> u64
pub fn payload_bytes_count(&self) -> u64
Returns the number of bytes in the payload of the Quic packet